/* clipboard.h -- manipulates clipboard

 * Copyright (C) 1999 Yarick Rastrigin <yarick@relex.ru>
 *                    Steve Hill <sjhill@plutonium.net>
 *                    Dany de Bontridder <dany.db@tvd.be>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>
#include <glib.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <errno.h>
#include <fcntl.h>
#include <unistd.h>
#include <dirent.h>
#include "clipboard.h"
#include "common.h"
#include "rq.h"
#include "addons.h"
#include "make_dir_list.h"
#include "tree.h"
#include "gvfs.h"


static FILE *clipboard_file = NULL;
static GList *selection = NULL;
gint last_clipboard_op = 0;
static gchar *source_dir = NULL;

void
init_clipboard ()
{
  gchar *full_clip_path = g_malloc0 (PATH_MAX);
  strncpy (full_clip_path, getenv ("HOME"), PATH_MAX - 1);
  strcat (full_clip_path, "/");
  strcat (full_clip_path, CLIPBOARD_PATH);
  clipboard_file = fopen (full_clip_path, "w");
  if (clipboard_file == NULL)
#ifdef  __DEBUG__
    {
      debug_out ("Cannot initialise clipboard !");
#endif
      exit (1);
#ifdef __DEBUG__
    };
#endif
  source_dir = g_malloc0 (PATH_MAX);
}

void
shut_clipboard ()
{
  if (clipboard_file != NULL)
    {
      fclose (clipboard_file);
    };
  g_free (source_dir);
}


void
get_selection ()
{
  GList *hGL1 = selection;
  for (; hGL1 != NULL; hGL1 = hGL1->next)
    g_free (hGL1->data);
  g_list_free (selection);
  selection = NULL;
  if ((selection = get_filelist_selection ()) == NULL)
    selection = get_tree_selection ();
  source_dir = gvfs_get_current_dir ();
  /* Insert selection saving here */
}

void
cut ()
{
  get_selection ();
  last_clipboard_op = CUT;
  //gvfs_move(hGL1, clipboard_path, gvfs_get_current_dir());
}

void
copy ()
{
  get_selection ();
  last_clipboard_op = COPY;
//    gvfs_copy(hGL1, clipboard_path, gvfs_get_current_dir());
}

/*
 */
void
paste ()
{
  GList *ret_struct = NULL;
  ret_struct = g_list_append (ret_struct, g_strdup (source_dir));
  ret_struct = g_list_append (ret_struct, gvfs_get_current_dir ());
  ret_struct = g_list_append (ret_struct, selection);
  putRequest (DO_COPY, ret_struct, (void *) last_clipboard_op);
}

void
delete ()
{
  GList *ret_struct = NULL;
  get_selection ();
  ret_struct = g_list_append (ret_struct, gvfs_get_current_dir ());
  ret_struct = g_list_append (ret_struct, gvfs_get_current_dir ());
  ret_struct = g_list_append (ret_struct, selection);
  putRequest (DO_COPY, ret_struct, (void *) DELETE_FILES);
}
